小爱音箱操控面板

## 小爱音箱设置面板 ( 版本未知 )

*勾选设备(至少勾选1个):
*小米账号: *小米密码: *XIAOMUSIC_HOSTNAME(IP或域名):

是否开启调试日志:
设备分组配置: 音乐目录: 音乐下载目录(必须是music的子目录): 配置文件目录: 缓存文件目录: ffmpeg路径: 日志路径: 允许唤醒的命令: 忽略目录(逗号分割): 目录深度: XIAOMUSIC_SEARCH(歌曲下载方式):
XIAOMUSIC_PROXY(ytsearch需要): 去除MP3 ID3v2和填充:
转换为MP3:
MiIO sst 指令: 关闭控制台密码验证:
控制台账户: 控制台密码: 关闭下载功能:
触屏版显示歌曲ID: 触屏版显示歌曲分段ID: 模糊匹配阈值(0.1~0.9): 开启模糊搜索:
型号兼容模式:
启用继续播放(可能导致兼容性问题):
监听端口(修改后需要重启): 外网访问端口(0表示跟监听端口一致): 获取对话记录间隔(秒): 下一首歌延迟播放秒数: 停止提示音: 播放本地歌曲口令: 播放歌曲口令: 停止口令: 启用yt-dlp-cookies(需要先上传yt-dlp-cookies.txt文件):
特殊型号获取对话记录:
歌单地址: 歌单内容:格式文档 定时任务:格式文档

上传yt_dlp_cookies.txt文件:文档

下载日志文件

m3u文件转换 歌曲下载工具

调试工具 💰 爱发电 点个 Star ⭐